@@ -29,9 +29,8 @@ LANG=C
 # overcloud deploy script for OVN migration.
 : ${OVERCLOUD_OVN_DEPLOY_SCRIPT:=~/overcloud-deploy-ovn.sh}
 
-# Is the present deployment DVR or HA. Lets assume it's HA
-: ${IS_DVR_ENABLED:=False}
 : ${OPT_WORKDIR:=$PWD}
+: ${STACK_NAME:=overcloud}
 : ${PUBLIC_NETWORK_NAME:=public}
 : ${IMAGE_NAME:=cirros}
 : ${SERVER_USER_NAME:=cirros}
@@ -65,11 +64,15 @@ file again."
         exit 1
     fi
 
-    cat $OVERCLOUD_OVN_DEPLOY_SCRIPT  | grep  $HOME/ovn-extras.yaml >/dev/null
-    if [ "$?" == "1" ]
+    cat $OVERCLOUD_OVN_DEPLOY_SCRIPT | grep \$HOME/ovn-extras.yaml >/dev/null
+    check1=$?
+    cat $OVERCLOUD_OVN_DEPLOY_SCRIPT | grep $HOME/ovn-extras.yaml >/dev/null
+    check2=$?
+
+    if [[ "$check1" == "1" && "$check2" == "1" ]]
     then
         echo "ovn-extras.yaml file is missing in $OVERCLOUD_OVN_DEPLOY_SCRIPT.\
- Please add it as \" -e $HOME/ovn-extras.yaml\""
+ Please add it as \" -e \$HOME/ovn-extras.yaml\""
         exit 1
     fi
 }
@@ -77,35 +80,23 @@ file again."
 get_host_ip() {
     inventory_file=$1
     host_name=$2
-    ip=`jq -r --arg role _meta --arg hostname $host_name 'to_entries[] | select(.key == $role) | .value.hostvars[$hostname].management_ip' $inventory_file`
-    if [[ "x$ip" == "x" ]] || [[ "x$ip" == "xnull" ]]; then
-        # This file does not provide translation from the hostname to the IP, or
-        # we already have an IP (Queens backwards compatibility)
-        echo $host_name
+    host_vars=$(ansible-inventory -i "$inventory_file" --host "$host_name" 2>/dev/null)
+    if [[ $? -eq 0 ]]; then
+        echo "$host_vars" | jq -r \.ansible_host
     else
-        echo $ip
+        echo $host_name
     fi
 }
 
-get_role_hosts() {
+get_group_hosts() {
     inventory_file=$1
-    role_name=$2
-    roles=`jq -r  \.$role_name\.children\[\] $inventory_file`
-    for role in $roles; do
-        # During the rocky cycle the format changed to have .value.hosts
-        hosts=`jq -r --arg role "$role" 'to_entries[] | select(.key == $role) | .value.hosts[]' $inventory_file`
-        if [[ "x$hosts" == "x" ]]; then
-            # But we keep backwards compatibility with nested childrens (Queens)
-            hosts=`jq -r --arg role "$role" 'to_entries[] | select(.key == $role) | .value.children[]' $inventory_file`
-
-            for host in $hosts; do
-               HOSTS="$HOSTS `jq -r --arg host "$host" 'to_entries[] | select(.key == $host) | .value.hosts[0]' $inventory_file`"
-            done
-        else
-            HOSTS="${hosts} ${HOSTS}"
-        fi
-    done
-    echo $HOSTS
+    group_name=$2
+    group_graph=$(ansible-inventory -i "$inventory_file" --graph "$group_name" 2>/dev/null)
+    if [[ $? -eq 0 ]]; then
+        echo "$group_graph" | sed -ne 's/^[ \t|]\+--\([a-z0-9\-]\+\)$/\1/p'
+    else
+        echo ""
+    fi
 }
 
 # Generate the ansible.cfg file
@@ -138,15 +129,15 @@ generate_ansible_inventory_file() {
     source $STACKRC_FILE
     echo "[ovn-dbs]"  > hosts_for_migration
     ovn_central=True
-    /usr/bin/tripleo-ansible-inventory --list > /tmp/ansible-inventory.txt
+    inventory_file=$(mktemp --tmpdir ansible-inventory-XXXXXXXX.yaml)
+    /usr/bin/tripleo-ansible-inventory --stack $STACK_NAME --static-yaml-inventory "$inventory_file"
     # We want to run ovn_dbs where neutron_api is running
-    OVN_DBS=$(get_role_hosts /tmp/ansible-inventory.txt neutron_api)
+    OVN_DBS=$(get_group_hosts "$inventory_file" neutron_api)
     for node_name in $OVN_DBS
     do
-        node_ip=$(get_host_ip /tmp/ansible-inventory.txt $node_name)
+        node_ip=$(get_host_ip "$inventory_file" $node_name)
         node="$node_name ansible_host=$node_ip"
-        if [ "$ovn_central" == "True" ]
-        then
+        if [ "$ovn_central" == "True" ]; then
             ovn_central=False
             node="$node_name ansible_host=$node_ip ovn_central=true"
         fi
@@ -157,13 +148,13 @@ generate_ansible_inventory_file() {
     echo "[ovn-controllers]" >> hosts_for_migration
 
     # We want to run ovn-controller where OVS agent was running before the migration
-    OVN_CONTROLLERS=$(get_role_hosts /tmp/ansible-inventory.txt neutron_ovs_agent)
+    OVN_CONTROLLERS=$(get_group_hosts "$inventory_file" neutron_ovs_agent)
     for node_name in $OVN_CONTROLLERS
     do
-        node_ip=$(get_host_ip /tmp/ansible-inventory.txt $node_name)
+        node_ip=$(get_host_ip "$inventory_file" $node_name)
         echo $node_name ansible_host=$node_ip ansible_ssh_user=heat-admin ansible_become=true ovn_controller=true >> hosts_for_migration
     done
-    rm -f /tmp/ansible-inventory.txt
+    rm -f "$inventory_file"
     echo "" >> hosts_for_migration
 
     cat >> hosts_for_migration << EOF
@@ -182,7 +173,6 @@ EOF
 
 [$1:vars]
 remote_user=heat-admin
-dvr_setup=$IS_DVR_ENABLED
 public_network_name=$PUBLIC_NETWORK_NAME
 image_name=$IMAGE_NAME
 working_dir=$OPT_WORKDIR
@@ -202,9 +192,42 @@ EOF
     cat hosts_for_migration
     echo "***************************************"
     echo "Generated the inventory file - hosts_for_migration"
-    echo "Please review the file before running the next command - reduce-mtu"
+    echo "Please review the file before running the next command - setup-mtu-t1"
 }
 
+# Check if the stack exists
+function check_stack {
+    source $STACKRC_FILE
+    openstack stack show $STACK_NAME 1> /dev/null || {
+        echo "ERROR: STACK_NAME=${STACK_NAME} does not exist. Please provide the stack name or its ID "
+        echo "       via STACK_NAME environment variable."
+        exit 1
+    }
+}
+
+# Check if the public network exists, and if it has floating ips available
+
+oc_check_public_network() {
+
+    source $OVERCLOUDRC_FILE
+    openstack network show $PUBLIC_NETWORK_NAME 1>/dev/null || {
+        echo "ERROR: PUBLIC_NETWORK_NAME=${PUBLIC_NETWORK_NAME} can't be accessed by the"
+        echo "       admin user, please fix that before continuing."
+        exit 1
+    }
+
+    ID=$(openstack floating ip create $PUBLIC_NETWORK_NAME -c id -f value) || {
+        echo "ERROR: PUBLIC_NETWORK_NAME=${PUBLIC_NETWORK_NAME} doesn't have available"
+        echo "       floating ips. Make sure that your public network has at least one"
+        echo "       floating ip available for the admin user."
+        exit 1
+    }
+
+    openstack floating ip delete $ID 2>/dev/null 1>/dev/null
+    return $?
+}
+
+
 # Check if the neutron networks MTU has been updated to geneve MTU size or not.
 # We donot want to proceed if the MTUs are not updated.
 oc_check_network_mtu() {
@@ -301,6 +324,8 @@ command=$1
 ret_val=0
 case $command in
     generate-inventory)
+        check_stack
+        oc_check_public_network
         generate_ansible_inventory_file
         generate_ansible_config_file
         ret_val=$?
@@ -317,6 +342,7 @@ case $command in
         ret_val=$?;;
 
     start-migration)
+        oc_check_public_network
         check_for_necessary_files
         shift
         start_migration $*
