@@ -38,8 +38,10 @@ class MetadataAgentOvnSbIdl(ovsdb_monitor.OvnIdl):
             helper.register_table(table)
         super(MetadataAgentOvnSbIdl, self).__init__(
             None, connection_string, helper)
-        if chassis and 'Chassis' in tables:
-            self.tables['Chassis'].condition = [['name', '==', chassis]]
+        if chassis:
+            table = ('Chassis_Private' if 'Chassis_Private' in tables
+                     else 'Chassis')
+            self.tables[table].condition = [['name', '==', chassis]]
         if events:
             self.notify_handler.watch_events(events)
 
@@ -64,7 +66,9 @@ class MetadataAgentOvsIdl(object):
         tables = ('Open_vSwitch', 'Bridge', 'Port', 'Interface')
         for table in tables:
             helper.register_table(table)
-        ovs_idl = idl.Idl(connection_string, helper)
+        ovs_idl = idl.Idl(
+            connection_string, helper,
+            probe_interval=config.get_ovn_ovsdb_probe_interval())
         conn = connection.Connection(
             ovs_idl, timeout=config.cfg.CONF.ovs.ovsdb_connection_timeout)
         return idl_ovs.OvsdbIdl(conn)
