@@ -16,6 +16,7 @@ import hashlib
 import hmac
 
 from neutron.agent.linux import utils as agent_utils
+from neutron.common import ipv6_utils
 from neutron.conf.agent.metadata import config
 from neutron_lib.callbacks import events
 from neutron_lib.callbacks import registry
@@ -25,7 +26,7 @@ from oslo_log import log as logging
 from oslo_utils import encodeutils
 import requests
 import six
-import six.moves.urllib.parse as urlparse
+from six.moves import urllib
 import webob
 
 from networking_ovn._i18n import _
@@ -56,7 +57,8 @@ class MetadataProxyHandler(object):
     def post_fork_initialize(self, resource, event, trigger, payload=None):
         # We need to open a connection to OVN SouthBound database for
         # each worker so that we can process the metadata requests.
-        self.sb_idl = ovsdb.MetadataAgentOvnSbIdl().start()
+        self.sb_idl = ovsdb.MetadataAgentOvnSbIdl(
+            tables=('Port_Binding', 'Datapath_Binding')).start()
 
     @webob.dec.wsgify(RequestClass=webob.Request)
     def __call__(self, req):
@@ -82,10 +84,22 @@ class MetadataProxyHandler(object):
 
         ports = self.sb_idl.get_network_port_bindings_by_ip(network_id,
                                                             remote_address)
-        if len(ports) == 1:
+        num_ports = len(ports)
+        if num_ports == 1:
             external_ids = ports[0].external_ids
             return (external_ids[ovn_const.OVN_DEVID_EXT_ID_KEY],
                     external_ids[ovn_const.OVN_PROJID_EXT_ID_KEY])
+        elif num_ports == 0:
+            LOG.error("No port found in network %s with IP address %s",
+                      network_id, remote_address)
+        elif num_ports > 1:
+            port_uuids = ', '.join([str(port.uuid) for port in ports])
+            LOG.error("More than one port found in network %s with IP address "
+                      "%s. Please run the neutron-ovn-db-sync-util script as "
+                      "there seems to be inconsistent data between Neutron "
+                      "and OVN databases. OVN Port uuids: %s", network_id,
+                      remote_address, port_uuids)
+
         return None, None
 
     def _proxy_request(self, instance_id, tenant_id, req):
@@ -96,10 +110,11 @@ class MetadataProxyHandler(object):
             'X-Instance-ID-Signature': self._sign_instance_id(instance_id)
         }
 
-        nova_host_port = '%s:%s' % (self.conf.nova_metadata_host,
-                                    self.conf.nova_metadata_port)
+        nova_host_port = ipv6_utils.valid_ipv6_url(
+            self.conf.nova_metadata_host,
+            self.conf.nova_metadata_port)
 
-        url = urlparse.urlunsplit((
+        url = urllib.parse.urlunsplit((
             self.conf.nova_metadata_protocol,
             nova_host_port,
             req.path_info,
