@@ -416,7 +416,7 @@ def get_system_dns_resolvers(resolver_file=DNS_RESOLVER_FILE):
 
 
 def get_port_subnet_ids(port):
-    fixed_ips = [ip for ip in port['fixed_ips']]
+    fixed_ips = list(port['fixed_ips'])
     return [f['subnet_id'] for f in fixed_ips]
 
 
