@@ -14,6 +14,7 @@
 #    under the License.
 
 from neutron_lib.db import model_base
+from oslo_utils import timeutils
 import sqlalchemy as sa
 from sqlalchemy.dialects import sqlite
 
@@ -31,10 +32,21 @@ class OVNRevisionNumbers(model_base.BASEV2):
     resource_type = sa.Column(sa.String(36), nullable=False, primary_key=True)
     revision_number = sa.Column(
         sa.BigInteger().with_variant(sa.Integer(), 'sqlite'),
-        server_default='0', nullable=False)
+        default=0, nullable=False)
     created_at = sa.Column(
         sa.DateTime().with_variant(
             sqlite.DATETIME(truncate_microseconds=True), 'sqlite'),
-        default=sa.func.now())
-    updated_at = sa.Column(sa.TIMESTAMP, server_default=sa.func.now(),
-                           onupdate=sa.func.now())
+        default=sa.func.now(), nullable=False)
+    updated_at = sa.Column(sa.TIMESTAMP, default=sa.func.now(),
+                           onupdate=sa.func.now(), nullable=True)
+
+
+class OVNHashRing(model_base.BASEV2):
+    __tablename__ = 'ovn_hash_ring'
+    node_uuid = sa.Column(sa.String(36), nullable=False, primary_key=True)
+    group_name = sa.Column(sa.String(256), nullable=False, primary_key=True)
+    hostname = sa.Column(sa.String(256), nullable=False)
+    created_at = sa.Column(sa.DateTime(), default=timeutils.utcnow,
+                           nullable=False)
+    updated_at = sa.Column(sa.DateTime(), default=timeutils.utcnow,
+                           nullable=False)
