@@ -42,6 +42,7 @@ from oslo_utils import timeutils
 from ovsdbapp.backend.ovs_idl import idlutils
 
 from networking_ovn._i18n import _
+from networking_ovn.agent import neutron_agent as n_agent
 from networking_ovn.common import acl as ovn_acl
 from networking_ovn.common import config
 from networking_ovn.common import constants as ovn_const
@@ -118,6 +119,9 @@ class OVNMechanismDriver(api.MechanismDriver):
         self.subscribe()
         self.qos_driver = qos_driver.OVNQosDriver.create(self)
         self.trunk_driver = trunk_driver.OVNTrunkDriver.create(self)
+        # The agent_chassis_table will be changed to Chassis_Private if it
+        # exists, we need to have a connection in order to check that.
+        self.agent_chassis_table = 'Chassis'
 
     @property
     def _plugin(self):
@@ -228,6 +232,9 @@ class OVNMechanismDriver(api.MechanismDriver):
         self._nb_ovn, self._sb_ovn = impl_idl_ovn.get_ovn_idls(
             self, trigger, binding_events=not is_maintenance)
 
+        if self._sb_ovn.is_table_present('Chassis_Private'):
+            self.agent_chassis_table = 'Chassis_Private'
+
         # AGENTS must be populated after fork so if ovn-controller is stopped
         # before a worker handles a get_agents request, we still show agents
         populate_agents(self)
@@ -631,7 +638,9 @@ class OVNMechanismDriver(api.MechanismDriver):
         # perform live-migration with live_migration_wait_for_vif_plug=True.
         if ((port['status'] == const.PORT_STATUS_DOWN and
              ovn_const.MIGRATING_ATTR in port[portbindings.PROFILE].keys() and
-             port[portbindings.VIF_TYPE] == portbindings.VIF_TYPE_OVS)):
+             port[portbindings.VIF_TYPE] in (
+                 portbindings.VIF_TYPE_OVS,
+                 portbindings.VIF_TYPE_VHOST_USER))):
             admin_context = n_context.get_admin_context()
             LOG.info("Setting port %s status from DOWN to UP in order "
                      "to emit vif-interface-plugged event.",
@@ -799,9 +808,6 @@ class OVNMechanismDriver(api.MechanismDriver):
 
     def _update_dnat_entry_if_needed(self, port_id, up=True):
         """Update DNAT entry if using distributed floating ips."""
-        if not config.is_ovn_distributed_floating_ip():
-            return
-
         if not self._nb_ovn:
             self._nb_ovn = self._ovn_client._nb_idl
 
@@ -821,17 +827,20 @@ class OVNMechanismDriver(api.MechanismDriver):
                                 {ovn_const.OVN_FIP_EXT_MAC_KEY:
                                  nat['external_mac']})).execute()
 
-        if up:
+        if up and config.is_ovn_distributed_floating_ip():
             mac = nat['external_ids'][ovn_const.OVN_FIP_EXT_MAC_KEY]
-            LOG.debug("Setting external_mac of port %s to %s",
-                      port_id, mac)
-            self._nb_ovn.db_set(
-                'NAT', nat['_uuid'],
-                ('external_mac', mac)).execute(check_error=True)
+            if nat['external_mac'] != mac:
+                LOG.debug("Setting external_mac of port %s to %s",
+                          port_id, mac)
+                self._nb_ovn.db_set(
+                    'NAT', nat['_uuid'], ('external_mac', mac)).execute(
+                    check_error=True)
         else:
-            LOG.debug("Clearing up external_mac of port %s", port_id)
-            self._nb_ovn.db_clear(
-                'NAT', nat['_uuid'], 'external_mac').execute(check_error=True)
+            if nat['external_mac']:
+                LOG.debug("Clearing up external_mac of port %s", port_id)
+                self._nb_ovn.db_clear(
+                    'NAT', nat['_uuid'], 'external_mac').execute(
+                    check_error=True)
 
     def _should_notify_nova(self, db_port):
         # NOTE(twilson) It is possible for a test to override a config option
@@ -997,87 +1006,36 @@ class OVNMechanismDriver(api.MechanismDriver):
                             " networking-ovn-metadata-agent status/logs.",
                             port_id)
 
-    def agent_alive(self, chassis, type_, update_db):
-        nb_cfg = chassis.nb_cfg
-        key = ovn_const.OVN_LIVENESS_CHECK_EXT_ID_KEY
-        if type_ == ovn_const.OVN_METADATA_AGENT:
-            nb_cfg = int(chassis.external_ids.get(
-                ovn_const.OVN_AGENT_METADATA_SB_CFG_KEY, 0))
-            key = ovn_const.METADATA_LIVENESS_CHECK_EXT_ID_KEY
-
-        try:
-            updated_at = timeutils.parse_isotime(chassis.external_ids[key])
-        except KeyError:
-            updated_at = timeutils.utcnow(with_timezone=True)
-            update_db = True
-
+    def agent_alive(self, agent, update_db):
         # Allow a maximum of 1 difference between expected and read values
         # to avoid false positives.
-        if self._nb_ovn.nb_global.nb_cfg - nb_cfg <= 1:
+        if self._nb_ovn.nb_global.nb_cfg - agent.nb_cfg <= 1:
             if update_db:
-                # update the time of our successful check
-                value = timeutils.utcnow(with_timezone=True).isoformat()
-                self._sb_ovn.db_set('Chassis', chassis.uuid,
-                                    ('external_ids', {key: value})).execute(
-                    check_error=True)
+                self.mark_agent_alive(agent)
             return True
-        now = timeutils.utcnow(with_timezone=True)
 
-        if (now - updated_at).total_seconds() < cfg.CONF.agent_down_time:
+        now = timeutils.utcnow(with_timezone=True)
+        if (now - agent.updated_at).total_seconds() < cfg.CONF.agent_down_time:
             # down, but not yet timed out
             return True
         return False
 
-    def _format_agent_info(self, chassis, binary, agent_id, type_,
-                           description, alive):
-        return {
-            'binary': binary,
-            'host': chassis.hostname,
-            'heartbeat_timestamp': timeutils.utcnow(),
-            'availability_zone': ', '.join(
-                utils.get_chassis_availability_zones(chassis)),
-            'topic': 'n/a',
-            'description': description,
-            'configurations': {
-                'chassis_name': chassis.name,
-                'bridge-mappings':
-                    chassis.external_ids.get('ovn-bridge-mappings', '')},
-            'start_flag': True,
-            'agent_type': type_,
-            'id': agent_id,
-            'alive': alive,
-            'admin_state_up': True}
+    def mark_agent_alive(self, agent):
+        # Update the time of our successful check
+        value = timeutils.utcnow(with_timezone=True).isoformat()
+        self._sb_ovn.db_set(
+            self.agent_chassis_table, agent.chassis_private.uuid,
+            ('external_ids', {agent.key: value})).execute(check_error=True)
 
-    def agents_from_chassis(self, chassis, update_db=True):
+    def agents_from_chassis(self, chassis_private, update_db=True):
         agent_dict = {}
-
-        # Check for ovn-controller / ovn-controller gateway
-        agent_type = ovn_const.OVN_CONTROLLER_AGENT
-        # Only the chassis name stays consistent after ovn-controller restart
-        agent_id = chassis.name
-        if ('enable-chassis-as-gw' in
-                chassis.external_ids.get('ovn-cms-options', [])):
-            agent_type = ovn_const.OVN_CONTROLLER_GW_AGENT
-
-        alive = self.agent_alive(chassis, agent_type, update_db)
-        description = chassis.external_ids.get(
-            ovn_const.OVN_AGENT_DESC_KEY, '')
-        agent_dict[agent_id] = self._format_agent_info(
-            chassis, 'ovn-controller', agent_id, agent_type, description,
-            alive)
-
-        # Check for the metadata agent
-        metadata_agent_id = chassis.external_ids.get(
-            ovn_const.OVN_AGENT_METADATA_ID_KEY)
-        if metadata_agent_id:
-            agent_type = ovn_const.OVN_METADATA_AGENT
-            alive = self.agent_alive(chassis, agent_type, update_db)
-            description = chassis.external_ids.get(
-                ovn_const.OVN_AGENT_METADATA_DESC_KEY, '')
-            agent_dict[metadata_agent_id] = self._format_agent_info(
-                chassis, 'networking-ovn-metadata-agent',
-                metadata_agent_id, agent_type, description, alive)
-
+        # Iterate over each unique Agent subclass
+        for agent in [a(chassis_private)
+                      for a in n_agent.NeutronAgent.agent_types()]:
+            if not agent.agent_id:
+                continue
+            alive = self.agent_alive(agent, update_db)
+            agent_dict[agent.agent_id] = agent.as_dict(alive)
         return agent_dict
 
     def patch_plugin_merge(self, method_name, new_fn, op=operator.add):
@@ -1099,12 +1057,12 @@ class OVNMechanismDriver(api.MechanismDriver):
             new_method = types.MethodType(new_fn, self._plugin)
             try:
                 return new_method(*args, _driver=self, **kwargs)
-            except KeyError:
+            except n_exc.NotFound:
                 return old_method(*args, **kwargs)
 
         setattr(self._plugin, method_name, types.MethodType(fn, self._plugin))
 
-    def ping_chassis(self):
+    def ping_all_chassis(self):
         """Update NB_Global.nb_cfg so that Chassis.nb_cfg will increment
 
         :returns: (bool) True if nb_cfg was updated. False if it was updated
@@ -1147,14 +1105,14 @@ class OVNMechanismDriver(api.MechanismDriver):
 
 
 def populate_agents(driver):
-    for ch in driver._sb_ovn.tables['Chassis'].rows.values():
+    for ch in driver._sb_ovn.tables[driver.agent_chassis_table].rows.values():
         # update the cache, rows are hashed on uuid but it is the name that
         # stays consistent across ovn-controller restarts
         AGENTS.update({ch.name: ch})
 
 
 def get_agents(self, context, filters=None, fields=None, _driver=None):
-    update_db = _driver.ping_chassis()
+    update_db = _driver.ping_all_chassis()
     filters = filters or {}
     agent_list = []
     populate_agents(_driver)
@@ -1168,11 +1126,12 @@ def get_agents(self, context, filters=None, fields=None, _driver=None):
 def get_agent(self, context, id, fields=None, _driver=None):
     chassis = None
     try:
-        # look up Chassis by *name*, which the id attribte is
-        chassis = _driver._sb_ovn.lookup('Chassis', id)
+        # look up Chassis by *name*, which the id attribute is
+        chassis = _driver._sb_ovn.lookup(_driver.agent_chassis_table, id)
     except idlutils.RowNotFound:
         # If the UUID is not found, check for the metadata agent ID
-        for ch in _driver._sb_ovn.tables['Chassis'].rows.values():
+        for ch in _driver._sb_ovn.tables[
+                _driver.agent_chassis_table].rows.values():
             metadata_agent_id = ch.external_ids.get(
                 ovn_const.OVN_AGENT_METADATA_ID_KEY)
             if id == metadata_agent_id:
