@@ -186,6 +186,11 @@ class OvnNbIdlForLb(ovsdb_monitor.OvnIdl):
              self.conn.stop(timeout=ovn_cfg.get_ovn_ovsdb_timeout()))):
             LOG.debug("Connection terminated to OvnNb "
                       "but a thread is still alive")
+        if hasattr(self, 'conn'):
+            if not self.conn.stop(timeout=ovn_cfg.get_ovn_ovsdb_timeout()):
+                LOG.debug("Connection terminated to OvnNb "
+                          "but a thread is still alive")
+            del self.conn
         # complete the shutdown for the event handler
         self.notify_handler.shutdown()
         # Close the idl session
@@ -281,6 +286,10 @@ class OvnProviderHelper(object):
         self.requests.put({'type': REQ_TYPE_EXIT})
         self.helper_thread.join()
         self.ovn_nb_idl_for_events.notify_handler.unwatch_events(self.events)
+        ovn_nbdb_api = OvnProviderHelper.ovn_nbdb_api
+        if ovn_nbdb_api:
+            OvnProviderHelper.ovn_nbdb_api = None
+            del ovn_nbdb_api
 
     @staticmethod
     def _map_val(row, col, key):
@@ -456,18 +465,24 @@ class OvnProviderHelper(object):
 
     def request_handler(self):
         while True:
-            try:
-                request = self.requests.get()
-                request_type = request['type']
-                if request_type == REQ_TYPE_EXIT:
-                    break
+            request = self.requests.get()
+            request_type = request['type']
+            if request_type == REQ_TYPE_EXIT:
+                break
 
-                request_handler = self._lb_request_func_maps.get(request_type)
+            request_handler = self._lb_request_func_maps.get(request_type)
+            try:
                 if request_handler:
                     status = request_handler(request['info'])
                     if status:
                         self._update_status_to_octavia(status)
                 self.requests.task_done()
+            except driver_exceptions.UpdateStatusError as e:
+                msg = ("Error while updating the load balancer "
+                       "status: %s") % e.fault_string
+                LOG.error(msg)
+                # TODO(haleyb): The resource(s) we were updating status for
+                # should be cleaned-up
             except Exception:
                 # If any unexpected exception happens we don't want the
                 # notify_loop to exit.
@@ -476,16 +491,16 @@ class OvnProviderHelper(object):
     def add_request(self, req):
         self.requests.put(req)
 
+    @tenacity.retry(
+        retry=tenacity.retry_if_exception_type(
+            driver_exceptions.UpdateStatusError),
+        wait=tenacity.wait_exponential(),
+        stop=tenacity.stop_after_delay(10),
+        reraise=True)
     def _update_status_to_octavia(self, status):
-        try:
-            status = OvnProviderHelper._delete_disabled_from_status(status)
-            LOG.debug('Updating status to octavia: %s', status)
-            self._octavia_driver_lib.update_loadbalancer_status(status)
-        except driver_exceptions.UpdateStatusError as e:
-            msg = ("Error while updating the load balancer "
-                   "status: %s") % e.fault_string
-            LOG.error(msg)
-            raise driver_exceptions.UpdateStatusError(msg)
+        status = OvnProviderHelper._delete_disabled_from_status(status)
+        LOG.debug('Updating status to octavia: %s', status)
+        self._octavia_driver_lib.update_loadbalancer_status(status)
 
     def _find_ovn_lbs(self, lb_id, protocol=None):
         """Find the Loadbalancers in OVN with the given lb_id as its name
@@ -939,7 +954,7 @@ class OvnProviderHelper(object):
                         break
 
         # If protocol set make sure its lowercase
-        protocol = protocol.lower() if protocol else None
+        protocol = protocol.lower() if protocol else []
         # In case port is not found for the vip_address we will see an
         # exception when port['id'] is accessed.
         external_ids = {
@@ -1960,6 +1975,16 @@ class OvnProviderDriver(driver_base.ProviderDriver):
                 user_fault_string=msg,
                 operator_fault_string=msg)
 
+    def _check_for_allowed_cidrs(self, allowed_cidrs):
+        # TODO(haleyb): add support for this
+        if isinstance(allowed_cidrs, o_datamodels.UnsetType):
+            allowed_cidrs = []
+        if allowed_cidrs:
+            msg = _('OVN provider does not support allowed_cidrs option')
+            raise driver_exceptions.UnsupportedOptionError(
+                user_fault_string=msg,
+                operator_fault_string=msg)
+
     def loadbalancer_create(self, loadbalancer):
         admin_state_up = loadbalancer.admin_state_up
         if isinstance(admin_state_up, o_datamodels.UnsetType):
@@ -2040,6 +2065,8 @@ class OvnProviderDriver(driver_base.ProviderDriver):
 
     def listener_create(self, listener):
         self._check_for_supported_protocols(listener.protocol)
+        self._check_for_allowed_cidrs(listener.allowed_cidrs)
+
         admin_state_up = listener.admin_state_up
         if isinstance(admin_state_up, o_datamodels.UnsetType):
             admin_state_up = True
@@ -2063,6 +2090,8 @@ class OvnProviderDriver(driver_base.ProviderDriver):
         self._ovn_helper.add_request(request)
 
     def listener_update(self, old_listener, new_listener):
+        self._check_for_allowed_cidrs(new_listener.allowed_cidrs)
+
         request_info = {'id': new_listener.listener_id,
                         'loadbalancer_id': old_listener.loadbalancer_id,
                         'protocol': old_listener.protocol,
