@@ -261,10 +261,9 @@ class TestDBInconsistenciesPeriodics(db_base.DBTestCase,
         port = {'id': 'port-id',
                 'device_id': 'router-id'}
         self.periodic._create_lrouter_port(port)
-        l3_mock = self.periodic._ovn_client._l3_plugin
-        l3_mock.add_router_interface.assert_called_once_with(
-            mock.ANY, port['device_id'], {'port_id': port['id']},
-            may_exist=True)
+        ovn_client_mock = self.periodic._ovn_client
+        ovn_client_mock.create_router_port.assert_called_once_with(
+            port['device_id'], mock.ANY)
 
     @mock.patch.object(maintenance.LOG, 'debug')
     def test__log_maintenance_inconsistencies(self, mock_log):
@@ -319,7 +318,7 @@ class TestDBInconsistenciesPeriodics(db_base.DBTestCase,
             attrs={'name': 'ls2',
                    'other_config': {
                         constants.MCAST_SNOOP: 'true',
-                        constants.MCAST_FLOOD_UNREGISTERED: 'true'}})
+                        constants.MCAST_FLOOD_UNREGISTERED: 'false'}})
 
         nb_idl._tables['Logical_Switch'].rows.values.return_value = [
             ls0, ls1, ls2]
@@ -333,11 +332,11 @@ class TestDBInconsistenciesPeriodics(db_base.DBTestCase,
             mock.call('Logical_Switch', 'ls0',
                       ('other_config', {
                            constants.MCAST_SNOOP: 'true',
-                           constants.MCAST_FLOOD_UNREGISTERED: 'true'})),
+                           constants.MCAST_FLOOD_UNREGISTERED: 'false'})),
             mock.call('Logical_Switch', 'ls1',
                       ('other_config', {
                            constants.MCAST_SNOOP: 'true',
-                           constants.MCAST_FLOOD_UNREGISTERED: 'true'})),
+                           constants.MCAST_FLOOD_UNREGISTERED: 'false'})),
         ]
         nb_idl.db_set.assert_has_calls(expected_calls)
 
