@@ -165,6 +165,8 @@ class FakeOvsdbSbOvnIdl(object):
         self.is_col_present.return_value = False
         self.lookup = mock.MagicMock()
         self.chassis_list = mock.MagicMock()
+        self.is_table_present = mock.Mock()
+        self.is_table_present.return_value = False
 
 
 class FakeOvsdbTransaction(object):
@@ -359,9 +361,29 @@ class FakeOvsdbRow(FakeResource):
         ovsdb_row_attrs.update(attrs)
         ovsdb_row_methods.update(methods)
 
-        return FakeResource(info=copy.deepcopy(ovsdb_row_attrs),
-                            loaded=True,
-                            methods=copy.deepcopy(ovsdb_row_methods))
+        result = FakeResource(info=copy.deepcopy(ovsdb_row_attrs),
+                              loaded=True,
+                              methods=copy.deepcopy(ovsdb_row_methods))
+        result.setkey.side_effect = lambda col, k, v: (
+                getattr(result, col).__setitem__(k, v))
+
+        def fake_addvalue(col, val):
+            try:
+                getattr(result, col).append(val)
+            except AttributeError:
+                # Not all tests set up fake rows to have all used cols
+                pass
+
+        def fake_delvalue(col, val):
+            try:
+                getattr(result, col).remove(val)
+            except (AttributeError, ValueError):
+                # Some tests also fake adding values
+                pass
+
+        result.addvalue.side_effect = fake_addvalue
+        result.delvalue.side_effect = fake_delvalue
+        return result
 
 
 class FakeOvsdbTable(FakeResource):
